==> boto3_type_annotations_with_docs-0.2.1-py3-none-any.whl: boto3_type_annotations/opsworkscm/waiter.py <==
from typing import NoReturn
from typing import Dict
from botocore.waiter import Waiter


class NodeAssociated(Waiter):
    def wait(self, NodeAssociationStatusToken: str, ServerName: str, WaiterConfig: Dict = None) -> NoReturn:
        """
        
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/opsworkscm-2016-11-01/DescribeNodeAssociationStatus>`_
        
        **Request Syntax** 
        ::
        
          waiter.wait(
              NodeAssociationStatusToken='string',
              ServerName='string',
              WaiterConfig={
                  'Delay': 123,
                  'MaxAttempts': 123
              }
          )
        :type NodeAssociationStatusToken: string
        :param NodeAssociationStatusToken: **[REQUIRED]** 
        
          The token returned in either the AssociateNodeResponse or the DisassociateNodeResponse. 
        
        :type ServerName: string
        :param ServerName: **[REQUIRED]** 
        
          The name of the server from which to disassociate the node. 
        
        :type WaiterConfig: dict
        :param WaiterConfig: 
        
          A dictionary that provides parameters to control waiting behavior.
        
          - **Delay** *(integer) --* 
        
            The amount of time in seconds to wait between attempts. Default: 15
        
          - **MaxAttempts** *(integer) --* 
        
            The maximum number of attempts to be made. Default: 15
        
        :returns: None
        """
        pass

==> boto3_type_annotations_with_docs-0.2.3-py3-none-any.whl: boto3_type_annotations/opsworkscm/waiter.py <==
from typing import NoReturn
from typing import Dict
from botocore.waiter import Waiter


class NodeAssociated(Waiter):
    def wait(self, NodeAssociationStatusToken: str, ServerName: str, WaiterConfig: Dict = None) -> NoReturn:
        """
        
        See also: `AWS API Documentation <https://docs.aws.amazon.com/goto/WebAPI/opsworkscm-2016-11-01/DescribeNodeAssociationStatus>`_
        
        **Request Syntax** 
        ::
        
          waiter.wait(
              NodeAssociationStatusToken=\'string\',
              ServerName=\'string\',
              WaiterConfig={
                  \'Delay\': 123,
                  \'MaxAttempts\': 123
              }
          )
        :type NodeAssociationStatusToken: string
        :param NodeAssociationStatusToken: **[REQUIRED]** 
        
          The token returned in either the AssociateNodeResponse or the DisassociateNodeResponse. 
        
        :type ServerName: string
        :param ServerName: **[REQUIRED]** 
        
          The name of the server from which to disassociate the node. 
        
        :type WaiterConfig: dict
        :param WaiterConfig: 
        
          A dictionary that provides parameters to control waiting behavior.
        
          - **Delay** *(integer) --* 
        
            The amount of time in seconds to wait between attempts. Default: 15
        
          - **MaxAttempts** *(integer) --* 
        
            The maximum number of attempts to be made. Default: 15
        
        :returns: None
        """
        pass
